// Copyright 2018 The Chromium OS Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef PERF_DATA_CONVERTER_SRC_QUIPPER_PROCESS_HEAP_PROFILE_H_
#define PERF_DATA_CONVERTER_SRC_QUIPPER_PROCESS_HEAP_PROFILE_H_

#include <string>

#include "compat/proto.h"
#include "kernel/perf_event.h"

namespace quipper {

// ProcessHeapProfile parses the given |heap_profile|, which is a raw text heap
// profile generated by the gperftools tcmalloc's API GetHeapSample, into a
// perf_data.proto using the heap_profile_parser, and the events are reordered
// so the mmap events appear before the sample events. Thus the sample events
// could be mapped. Performs address remapping, and fetches missing buildids
// using the given |pid|. On success, fills the given |out| with the generated
// perf_data.proto. Otherwise, returns false.
bool ProcessHeapProfile(const std::string& heap_profile, u32 pid,
                        PerfDataProto* out);

}  // namespace quipper

#endif  // PERF_DATA_CONVERTER_SRC_QUIPPER_PROCESS_HEAP_PROFILE_H_
